@@ -2,8 +2,8 @@
 export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
 echo 'name: pandoc-citeproc
 version: 0.9.1.1
-id: pandoc-citeproc-0.9.1.1-e33a750d478d5c454d26592c51122195
-key: pando_7dOJndVy6U3De7GmiOXrDC
+id: pandoc-citeproc-0.9.1.1-1d27415813eae935b120436dc23bd090
+key: pando_FR7BIejKllo93qfJu872TX
 license: BSD3
 maintainer: jgm@berkeley.edu
 homepage: https://github.com/jgm/pandoc-citeproc
@@ -42,9 +42,9 @@ trusted: False
 import-dirs: /usr/lib/ghc-7.10.3/site-local/pandoc-citeproc-0.9.1.1
 library-dirs: /usr/lib/ghc-7.10.3/site-local/pandoc-citeproc-0.9.1.1
 data-dir: /usr/share/pandoc-citeproc
-hs-libraries: HSpandoc-citeproc-0.9.1.1-7dOJndVy6U3De7GmiOXrDC
+hs-libraries: HSpandoc-citeproc-0.9.1.1-FR7BIejKllo93qfJu872TX
 depends:
-    aeson-0.11.1.1-ac1365b396a3746ecb25074345ed217b
+    aeson-0.11.1.4-4ad27f2347131dcc86b1af72cd00fe7c
     base-4.8.2.0-2f1f71a7fcf013cd47fd21f489064f9a
     bytestring-0.10.6.0-3b51e35daa3fe2a56ecd3687fb389cdc
     containers-0.5.6.2-169e53288f333dd2f0207994fd53822f
@@ -54,8 +54,8 @@ depends:
     hs-bibutils-5.5-91f8c150a94b021e3f1d7580075e1ca0
     mtl-2.2.1-c516313407bc17046965067cb7cbb6a0
     old-locale-1.0.0.7-5aedb410aa2e5fddd3c57e9b4de1f46a
-    pandoc-1.17.0.1-1c6da1ddfcd8a2619fb2ca103a269dd9
-    pandoc-types-1.16.1-0b1608b10c9621b9412cccf92ea53ad6
+    pandoc-1.17.0.3-a12df7a7745e5ea4de39fe36e7ff7b76
+    pandoc-types-1.16.1-5c682c2b5cffa962280d4abd090bac44
     parsec-3.1.9-3365ddffd9ca11d2f0b377e002b54baf
     setenv-0.1.1.3-4d70f2e61b1bd0645017164a0ca26ee9
     split-0.2.3-1755fd7a4bff52537a62f0056f73dfbc
@@ -67,7 +67,7 @@ depends:
     unordered-containers-0.2.7.0-d91279dcd5fa13d7f88095dc08e2fda6
     vector-0.11.0.0-711d35c4a6ac1ea2e529dc3ee3328963
     xml-conduit-1.3.4-afe40bd27d2aaa75347b019ed922ee43
-    yaml-0.8.16-8e3a1d884bd629b7e4f9063e0e319626
+    yaml-0.8.16-50dd72d7df25e45cd672d7359cb18648
 haddock-interfaces: /usr/share/doc/pandoc-citeproc/html/pandoc-citeproc.haddock
 haddock-html: /usr/share/doc/pandoc-citeproc/html
 ' | '/usr/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-db' "$@"
